necsummary of models fitted with the brms packageSingle models fitted with the
bayesnec package are summarised
as a necsummary object, which contains the original
brmsfit object summary, the name of the
non-linear model fitted, whether this model is an ECx-type model
(see details below), and the ECx summary values should the user decide
to calculate them.
brmssummaryThe standard summary for the fitted Bayesian model of
class brmsfit.
modelA character string indicating the name of
the fitted non-linear model.
is_ecxA logical indicating whether model
is an ECx-type model.
nec_valsThe NEC values. Note that if model is an ECx-type model, this estimate will be a NSEC proxy.
ecsA list containing the ECx values
should the user decide to calculate them (see the non-exported
bayesnec:::summary.bayesnecfit help file for details).
bayesr2The model Bayesian R2 as calculated by
bayes_R2.
See methods(class = "necsummary") for an overview of available
methods.
Fisher R, Barneche DR, Ricardo GF, Fox, DR (2024) An R Package for Concentration-Response Modeling and Estimation of Toxicity Metrics doi:10.18637/jss.v110.i05.
Fisher R, Fox DR (2023). Introducing the no significant effect concentration (NSEC).Environmental Toxicology and Chemistry, 42(9), 2019–2028. doi: 10.1002/etc.5610.
Fisher R, Fox DR, Negri AP, van Dam J, Flores F, Koppel D (2023). Methods for estimating no-effect toxicity concentrations in ecotoxicology. Integrated Environmental Assessment and Management. doi:10.1002/ieam.4809.
Fox DR (2010). A Bayesian Approach for Determining the No Effect Concentration and Hazardous Concentration in Ecotoxicology. Ecotoxicology and Environmental Safety, 73(2), 123–131. doi: 10.1016/j.ecoenv.2009.09.012.
bayesnec,
bnec,
bayesnecfit,
bayesmanecfit,
manecsummary